pub trait Deserialize<T, D>{
// Required method
fn deserialize(
&self,
deserializer: &mut D,
) -> Result<T, <D as Fallible>::Error>;
}Expand description
Converts a type back from its archived form.
Some types may require specific deserializer capabilities, such as Rc and
Arc. In these cases, the deserializer type D should be bound so that it
implements traits that provide those capabilities (e.g.
Pooling).
This can be derived with Deserialize.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".